@@ -42,8 +42,13 @@ pub(super) fn calc_quantity_and_volume(
             (quantity_quote / price, quantity_quote, Some(quantity))
         }
         MarketType::LinearSwap | MarketType::LinearFuture | MarketType::Move | MarketType::BVOL => {
-            let quantity_base = quantity * contract_value;
-            (quantity_base, quantity_base * price, Some(quantity))
+            if exchange == "bitmex" {
+                let quantity_quote = quantity * contract_value;
+                (quantity_quote / price, quantity_quote, Some(quantity))
+            } else {
+                let quantity_base = quantity * contract_value;
+                (quantity_base, quantity_base * price, Some(quantity))
+            }
         }
         _ => panic!("Unknown market_type {}", market_type),
     }
